EXPORTS
	??0RAcmServer@@QAE@XZ @ 1 NONAME ; RAcmServer::RAcmServer(void)
	??1RAcmServer@@QAE@XZ @ 2 NONAME ; RAcmServer::~RAcmServer(void)
	?Connect@RAcmServer@@QAEHXZ @ 3 NONAME ; int RAcmServer::Connect(void)
	?CreateFunctions@RAcmServer@@QAEHI@Z @ 4 NONAME ; int RAcmServer::CreateFunctions(unsigned int)
	?CreateFunctions@RAcmServer@@QAEHIE@Z @ 5 NONAME ; int RAcmServer::CreateFunctions(unsigned int, unsigned char)
	?DestroyFunctions@RAcmServer@@QAEHI@Z @ 6 NONAME ; int RAcmServer::DestroyFunctions(unsigned int)
	?Close@RAcmServer@@QAEXXZ @ 7 NONAME ; void RAcmServer::Close(void)
	?CreateFunctions@RAcmServer@@QAEHIEABVTDesC16@@0@Z @ 8 NONAME ; int RAcmServer::CreateFunctions(unsigned int, unsigned char, class TDesC16 const &, class TDesC16 const &)

